@@ -1,4 +1,4 @@
-VERSION = '0.7'
+VERSION = '0.9'
 
 from .design_flute import Design_tapered_pflute, Design_straight_pflute, Design_tapered_folk_flute, Design_straight_folk_flute
 from .make_flute import Make_flute
@@ -16,6 +16,8 @@ from .make_panpipe import Make_panpipe
 
 from .make_reed import Make_reed
 
+from .tune import Tune
+
 from .all import All
 
 def main():
@@ -48,6 +50,9 @@ def main():
             'Panpipes',        
             Make_panpipe,
             
+            'Utilities',
+            Tune,
+            
             #'Everything',        
             #All,
             #'"demakein all:" uses the nesoni make system, see flags below.',
