@@ -6,7 +6,7 @@ Note: pypy gc does not count c++ allocated memory, triggers major gc infrequentl
 
 """
 
-import os, cffi, subprocess, hashlib, gc, time
+import os, subprocess, hashlib, gc, time
 
 def update_file(filename, content):
     good = os.path.exists(filename)
@@ -60,8 +60,22 @@ class Box(object):
         return string
 
 
-class Module(object):
-    def __init__(self, build_dir, preamble, cmake_code=''):
+class Lazy_init(object):
+    def __init__(self, *args, **kwargs):
+        self._init_args = (args, kwargs)
+        self._init_done = False
+    
+    def __getattr__(self, name):
+        if not self._init_done:
+            self._lazy_init(*self._init_args[0],**self._init_args[1])
+            del self._init_args
+            self._init_done = True
+        return object.__getattribute__(self, name)
+
+class Module(Lazy_init):
+    def _lazy_init(self, build_dir, preamble, cmake_code=''):
+        import cffi
+        
         self.build_dir = build_dir
         self.preamble = preamble
         self.code = [ ]
@@ -90,8 +104,6 @@ class Module(object):
         except Exception:
             self.hint = [ ]
             
-        #self.load_code(hint)
-    
     def _gc_tick(self):
         t1 = time.time()
         if t1 >= self.gc_clock:
