@@ -133,7 +133,8 @@ def hole_length_correction(hole_diameter, bore_diameter, closed):
     
     # Maybe better to treat as bore deviation?
     
-    if closed: return 0.0
+    if closed: 
+       return 0.0
     
     # As per p.63-64 of Nederveen
     outer_correction = 0.7
@@ -141,6 +142,7 @@ def hole_length_correction(hole_diameter, bore_diameter, closed):
     a = hole_diameter / 2.0
     
     result = a * (inner_correction+outer_correction)
+
     return result
 
 
@@ -330,7 +332,6 @@ def sqrt_scaler(value):
         return [ item*scale if item is not None else None for item in value ]
     return func
 
-
 @config.Int_flag('transpose', 'Transpose instrument by this many semitones.')
 class Instrument_designer(config.Action_with_output_dir):
     instrument_class = Instrument
@@ -640,6 +641,7 @@ class Instrument_designer(config.Action_with_output_dir):
 
     
     def _save(self, state_vec, other_vecs=[]):
+        self.state_vec = state_vec
         self.instrument = self.unpack( state_vec )
         
         with open(os.path.join(self.output_dir, 'data.pickle'), 'wb') as f:
